summaryrefslogtreecommitdiffstats
path: root/superkaramba/examples/unicode
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:23:49 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-04 03:15:18 +0200
commita3f1234ece748a30d118e4b6f8333c19505bd516 (patch)
treef86bf3eb14b004c4e2e3bf9bf36e321dee3ce6b5 /superkaramba/examples/unicode
parent632b7d40cf87562965abb5c7dffc1bae509bad2c (diff)
downloadtdeutils-a3f1234ece748a30d118e4b6f8333c19505bd516.tar.gz
tdeutils-a3f1234ece748a30d118e4b6f8333c19505bd516.zip
Rename obsolete tq methods to standard names
(cherry picked from commit 89856e749bf14e63fed55a8f3436ea9a6f19667a)
Diffstat (limited to 'superkaramba/examples/unicode')
-rw-r--r--superkaramba/examples/unicode/unicode.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/superkaramba/examples/unicode/unicode.py b/superkaramba/examples/unicode/unicode.py
index 1a15f83..13d1136 100644
--- a/superkaramba/examples/unicode/unicode.py
+++ b/superkaramba/examples/unicode/unicode.py
@@ -1,6 +1,6 @@
#Unicode Example
#For Symbol Tables look at www.tqunicode.org/charts/
#this import statement allows access to the karamba functions
@@ -31,8 +31,8 @@ def initWidget(widget):
\u0631\u0632\u0633\u0634\u0635\u0636\u0637\u0638\u0639\u063A\u0641\u0642\u0643\u0644\u0645\u0646
\u0647\u0648\u064A
<p>
-For a complete reference on tqunicode caracter codes look at:
-<center><a href="kfmclient openURL http://www.tqunicode.org/charts/">www.tqunicode.org/charts/</a></center>
+For a complete reference on unicode caracter codes look at:
+<center><a href="kfmclient openURL http://www.unicode.org/charts/">www.unicode.org/charts/</a></center>
</p>
"""
karamba.resizeWidget(widget, 400, 400)
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.tqunicode.org/charts/
+#For Symbol Tables look at www.unicode.org/charts/
#this import statement allows access to the karamba functions